==> percona-server-mongodb_4.0.27.orig.tar.gz: percona-server-mongodb-4.0.27-22/src/mongo/db/storage/ephemeral_for_test/ephemeral_for_test_recovery_unit.h <==
// ephemeral_for_test_recovery_unit.h


/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <vector>

#include "mongo/db/record_id.h"
#include "mongo/db/storage/recovery_unit.h"
#include "mongo/stdx/functional.h"

namespace mongo {

class SortedDataInterface;

class EphemeralForTestRecoveryUnit : public RecoveryUnit {
public:
    EphemeralForTestRecoveryUnit(stdx::function<void()> cb = nullptr)
        : _waitUntilDurableCallback(cb) {}

    void beginUnitOfWork(OperationContext* opCtx) final{};
    void commitUnitOfWork() final;
    void abortUnitOfWork() final;

    virtual bool waitUntilDurable() {
        if (_waitUntilDurableCallback) {
            _waitUntilDurableCallback();
        }
        return true;
    }

    virtual void abandonSnapshot() {}

    Status obtainMajorityCommittedSnapshot() final;

    virtual void registerChange(Change* change) {
        _changes.push_back(ChangePtr(change));
    }

    virtual void* writingPtr(void* data, size_t len) {
        MONGO_UNREACHABLE;
    }

    virtual void setRollbackWritesDisabled() {}

    virtual SnapshotId getSnapshotId() const {
        return SnapshotId();
    }

    virtual void setOrderedCommit(bool orderedCommit) {}

private:
    typedef std::shared_ptr<Change> ChangePtr;
    typedef std::vector<ChangePtr> Changes;

    Changes _changes;
    stdx::function<void()> _waitUntilDurableCallback;
};

}  // namespace mongo

==> percona-server-mongodb_4.4.16.orig.tar.gz: percona-server-mongodb-4.4.16-16/src/mongo/db/storage/ephemeral_for_test/ephemeral_for_test_recovery_unit.h <==
/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <functional>
#include <vector>

#include "mongo/db/record_id.h"
#include "mongo/db/storage/recovery_unit.h"

namespace mongo {

class SortedDataInterface;

class EphemeralForTestRecoveryUnit : public RecoveryUnit {
public:
    EphemeralForTestRecoveryUnit(std::function<void()> cb = nullptr)
        : _waitUntilDurableCallback(cb) {}

    virtual ~EphemeralForTestRecoveryUnit();

    void beginUnitOfWork(OperationContext* opCtx) final;

    virtual bool waitUntilDurable(OperationContext* opCtx);

    bool inActiveTxn() const;

    Status obtainMajorityCommittedSnapshot() final;

    virtual void registerChange(std::unique_ptr<Change> change);

    virtual void setOrderedCommit(bool orderedCommit) {}

    virtual void prepareUnitOfWork() override {}

    virtual void setPrepareTimestamp(Timestamp ts) override {
        _prepareTimestamp = ts;
    }

    virtual Timestamp getPrepareTimestamp() const override {
        return _prepareTimestamp;
    }

    virtual void setCommitTimestamp(Timestamp ts) override {
        _commitTimestamp = ts;
    }

    virtual Timestamp getCommitTimestamp() const override {
        return _commitTimestamp;
    }

    virtual void clearCommitTimestamp() override {
        _commitTimestamp = Timestamp::min();
    }

private:
    void doCommitUnitOfWork() final;
    void doAbortUnitOfWork() final;

    void doAbandonSnapshot() final;

    typedef std::vector<std::shared_ptr<Change>> Changes;

    Changes _changes;
    std::function<void()> _waitUntilDurableCallback;

    Timestamp _prepareTimestamp = Timestamp::min();
    Timestamp _commitTimestamp = Timestamp::min();
};

}  // namespace mongo
